//===--- using_aliased_symbol-declare.h - test input file for iwyu --------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file is distributed under the University of Illinois Open Source
// License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//

class IndirectClass;

namespace ns {
void symbol();
typedef IndirectClass Typedef;
}  // namespace ns
